@@ -1,5 +1,9 @@
+from functools import partial
+import http
+from http.server import BaseHTTPRequestHandler, HTTPServer
 import os
 import signal
+import threading
 import traceback
 
 from adam.config import Config
@@ -10,6 +14,20 @@ from adam.commands.command import Command
 from adam.repl_state import ReplState
 from adam.utils import log2
 
+class TokenHandler(BaseHTTPRequestHandler):
+    def __init__(self, idp_token: str, *args, **kwargs):
+        self.idp_token = idp_token
+        super().__init__(*args, **kwargs)
+
+    def log_request(self, code='-', size='-'):
+        pass
+
+    def do_GET(self):
+        self.send_response(200)
+        self.send_header('Content-type', 'text/plain')
+        self.end_headers()
+        self.wfile.write(self.idp_token.encode('utf8'))
+
 class UserEntry(Command):
     COMMAND = 'entry'
 
@@ -25,6 +43,13 @@ class UserEntry(Command):
     def command(self):
         return UserEntry.COMMAND
 
+    def run_token_server(port: int, idp_token: str):
+        server_address = ('localhost', port)
+        handler = partial(TokenHandler, idp_token)
+        httpd = HTTPServer(server_address, handler)
+        print(f"Serving on port {port}")
+        httpd.serve_forever()
+
     def run(self, cmd: str, state: ReplState):
         def custom_handler(signum, frame):
             AppSession.ctrl_c_entered = True
@@ -59,11 +84,18 @@ class UserEntry(Command):
 
                 Config().debug(traceback.format_exc())
 
+        server_port = 8000
+        server_thread = threading.Thread(target=UserEntry.run_token_server, args=(server_port, login.ser()), daemon=True)
+        server_thread.start()
+
         sh = f'{os.getcwd()}/login.sh'
         if not os.path.exists(sh):
             sh = f'{os.getcwd()}/docker/login.sh'
 
-        os.system(f'{sh} {login.shell_user()} {login.ser()}')
+        if os.getenv('PASS_DOWN_IDP_TOKEN', "true").lower() == "true":
+            os.system(f'{sh} {login.shell_user()} {server_port} {login.ser()}')
+        else:
+            os.system(f'{sh} {login.shell_user()} {server_port}')
 
         return state
 
