@@ -1,4 +1,6 @@
 import getpass
+import os
+import requests
 
 from .cred_cache import CredCache
 from .idp_session import IdpSession
@@ -21,6 +23,10 @@ class Idp:
         if use_token_from_env:
             if l0 := session.login_from_env_var():
                 return l0
+        if p := os.getenv("SERVER_PORT"):
+            res: requests.Response = requests.get(f'localhost:{p}')
+            if res.status_code == 200 and res.text:
+                return res.text
 
         r: IdpLogin = None
         try:
